netapp_ontap.models.cifs_service_delete API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cifs_service_delete`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class CifsServiceDeleteSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the CifsServiceDelete object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `ad_domain: AdDomainDelete GET POST PATCH`

    The ad_domain field of the cifs_service_delete.

  `auth_user_type: str GET POST PATCH`

    Specifies the type of user who can access the SMB Volume. The default is domain_user. In the case of a hybrid-user, ONTAP won't contact on-premise ADDS.

    Valid choices:

    - domain_user
    - hybrid_user
  `authentication_method: str GET POST PATCH`

    Specifies the authentication method. The available values are:

    - client_secret
    - certificate

    Valid choices:

    - client_secret
    - certificate
  `client_certificate: str POST PATCH`

    PKCS12 certificate used by the application to prove its identity to AKV.

    Example: PEM Cert

  `client_id: str GET POST PATCH`

    Application client ID of the deployed Azure application with appropriate access to an AKV or EntraId.

    Example: e959d1b5-5a63-4284-9268-851e30e3eceb

  `client_secret: str POST PATCH`

    Secret used by the application to prove its identity to AKV.

    Example:

  `key_vault_uri: str GET POST PATCH`

    URI of the deployed AKV that is used by ONTAP for storing keys.

    Example: https://kmip-akv-keyvault.vault.azure.net/

  `oauth_host: str GET POST PATCH`

    Open authorization server host name.

    Example: login.microsoftonline.com

  `proxy_host: str GET POST PATCH`

    Proxy host.

    Example: proxy.eng.com

  `proxy_password: str POST PATCH`

    Proxy password. Password is not audited.

    Example: proxypassword

  `proxy_port: Size GET POST PATCH`

    Proxy port.

    Example: 1234

  `proxy_type: str GET POST PATCH`

    Proxy type.

    Valid choices:

    - http
    - https
  `proxy_username: str GET POST PATCH`

    Proxy username.

    Example: proxyuser

  `tenant_id: str GET POST PATCH`

    Directory (tenant) ID of the deployed Azure application with appropriate access to an AKV or EntraId.

    Example: c9f32fcb-4ab7-40fe-af1b-1850d46cfbbe

  `timeout: Size GET POST PATCH`

    AKV connection timeout, in seconds. The allowed range is between 0 to 30 seconds.

    Example: 25

  `verify_host: bool GET POST PATCH`

    Verify the identity of the AKV host name. By default, verify_host is set to true.

  `workgroup: str GET POST PATCH`

    The workgroup name.

    Example: workgrp1